distFitMonotoneSymmetric takes the variance stabilized count values and
calculates a symmetric monotone fit for the distance dependency. The position
information about the viewpoint is stored in fragData.
The signal trend is fitted for the combined data left and right to the viewpoint
using the fda package.
distFitMonotoneSymmetric(count, fragData, alpha = 20, penalty = 0.1, removeZeros = FALSE, ...)floor((max(number of fragments left or right))/alpha) is passed to
create.bspline.basis as nbasis argument (if this value is smaller
than 4, 4 is the default value). Default is 20.fdPar as lambda argument.
Default is 0.1.FALSE.