getZScores calculates the z-score for each fragment within a
distance from the viewpoint defined by distAroundVP. For the
calculation the count data is first transformed with a variance stabilizing
transformation from the DESeq2 package. The decay trend of this transformed
data with distance from the viewpoint is fitted either with local regression
model using locfit or a monotone decay fit using the fda package.
z-scores are finally calculated from the residuals of the fit values.
getZScores(object, removeZeros = TRUE, minCount = 40, minDist = NULL, fitFun = "distFitMonotoneSymmetric", sdFun = mad, ...)FourC object.TRUE.40NULL), the borders of the
viewpoint peak are estimated as the minimum values next to the viewpoint before
the signal rises again.distFitMonotoneSymmetric (default),
distFitMonotone or any self-defined function to fit the distance dependency.mad.distFitMonotone, distFitMonotoneSymmetric).FourC object for the selected viewpoint
with z-score values for all fragments on the viewpoint chromosome that
passed the minCount threshold and that were not too close to the
viewpoint. All additional required data is saved in the object. Especially
the following information is added to the FourC object:
FourC, countFragmentOverlaps,
distFitMonotone, distFitMonotoneSymmetric
data(fc, package="FourCSeq")
fcf <- getZScores(fc)
fcf
Run the code above in your browser using DataLab